==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/entity/property_date.model.dart <==
part of tecfy_corev2_client_package;

class PropertyDate extends Property {
  DateTime? minDate;
  DateTime? maxDate;

  bool isTodayByDefault = false;

  bool isAllowFuture = true;
  bool isAllowPast = true;

  /// <summary>
  /// yyyy-MM-dd    (default)
  /// dd/MM/yyyy
  /// </summary>
  late String format;

  PropertyDate(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.format = "yyyy-MM-dd",
      this.isTodayByDefault = false})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyDate.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    minDate = getDateFromJsonString(row['minDate'] ?? '2000-01-01');
    maxDate = getDateFromJsonString(row['maxDate'] ?? '2050-01-01');
    isTodayByDefault = row['isTodayByDefault'] ?? false;
    isAllowFuture = row['isAllowFuture'] ?? true;
    isAllowPast = row['isAllowPast'] ?? true;
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  DateTime? getDateFromJsonString(String value) {
    return BaseModel.parseUTC(value);
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    var date = data[dbName] is DateTime
        ? data[dbName]
        : BaseModel.parseUTC(data[dbName]);

    return date == null ? '' : intl.DateFormat(format).format(date.toLocal());
  }

  // static Widget getDisplay(dynamic value,
  //     [String? format, Color color = Colors.black, double size = 10]) {
  //   var date = value is DateTime ? value : BaseModel.parseUTC(value);
  //   return Text(
  //       date == null
  //           ? ''
  //           : intl.DateFormat(format ?? "yyyy-MM-dd HH:mm")
  //               .format(date.toLocal()),
  //       style: TextStyle(fontSize: size, color: color));
  // }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    if (isTodayByDefault) {
      data[dbName] = DateTime.now().toUtc();
      return true;
    }
    return false;
  }
}

==> tecfy_corev2_package-1.1.117.tar.gz: lib/models/entity/property_date.model.dart <==
part of tecfy_corev2_client_package;

class PropertyDate extends Property {
  DateTime? minDate;
  DateTime? maxDate;

  bool isTodayByDefault = false;

  bool isAllowFuture = true;
  bool isAllowPast = true;

  /// <summary>
  /// yyyy-MM-dd    (default)
  /// dd/MM/yyyy
  /// </summary>
  late String format;

  PropertyDate(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.format = "yyyy-MM-dd",
      this.isTodayByDefault = false})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyDate.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    minDate = getDateFromJsonString(row['minDate'] ?? '2000-01-01');
    maxDate = getDateFromJsonString(row['maxDate'] ?? '2050-01-01');
    isTodayByDefault = row['isTodayByDefault'] ?? false;
    isAllowFuture = row['isAllowFuture'] ?? true;
    isAllowPast = row['isAllowPast'] ?? true;
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  DateTime? getDateFromJsonString(String value) {
    return BaseModel.parseUTC(value);
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    var value = MapService.getValue(data, dbName);
    var date = value is DateTime ? value : BaseModel.parseUTC(value);

    return date == null ? '' : intl.DateFormat(format).format(date.toLocal());
  }

  // static Widget getDisplay(dynamic value,
  //     [String? format, Color color = Colors.black, double size = 10]) {
  //   var date = value is DateTime ? value : BaseModel.parseUTC(value);
  //   return Text(
  //       date == null
  //           ? ''
  //           : intl.DateFormat(format ?? "yyyy-MM-dd HH:mm")
  //               .format(date.toLocal()),
  //       style: TextStyle(fontSize: size, color: color));
  // }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null) return false;
    if (isTodayByDefault) {
      // data[dbName] = DateTime.now().toUtc();
      MapService.updateValue(data, dbName, DateTime.now().toUtc());
      return true;
    }
    return false;
  }
}
